@@ -71,7 +71,7 @@
 #include <QTextDocumentWriter>
 #include <QUrl>
 
-#include <MauiKit/Core/fmh.h>
+#include <MauiKit3/Core/fmh.h>
 
 #if defined Q_OS_MACOS || defined Q_OS_WIN32
 #include <KF5/KSyntaxHighlighting/Definition>
@@ -111,7 +111,7 @@ QVariant Alerts::data(const QModelIndex &index, int role) const
 {
     if (role == ROLES::ALERT)
         return QVariant::fromValue(this->m_alerts.at(index.row()));
-    
+
     return QVariant();
 }
 
@@ -119,7 +119,7 @@ int Alerts::rowCount(const QModelIndex &parent) const
 {
     if (parent.isValid())
         return 0;
-    
+
     return this->m_alerts.count();
 }
 
@@ -134,7 +134,7 @@ bool Alerts::contains(DocumentAlert *const alert)
         if (alert_->getId() == alert->getId())
             return true;
     }
-    
+
     return false;
 }
 
@@ -142,10 +142,10 @@ void Alerts::append(DocumentAlert *alert)
 {
     if (this->contains(alert))
         return;
-    
+
     const auto index = this->rowCount();
     beginInsertRows(QModelIndex(), index, index);
-    
+
     // watch out for when the alert is done: such as when an action is triggered
     connect(alert, &DocumentAlert::done, [this](int index) {
         this->beginRemoveRows(QModelIndex(), index, index);
@@ -156,7 +156,7 @@ void Alerts::append(DocumentAlert *alert)
         }
         this->endRemoveRows();
     });
-    
+
     alert->setIndex(index);
     this->m_alerts << alert;
     endInsertRows();
@@ -169,7 +169,7 @@ void FileLoader::loadFile(const QUrl &url)
         if (file.open(QFile::ReadOnly)) {
             const auto array = file.readAll();
             QTextCodec *codec = QTextDocumentWriter(url.toLocalFile()).codec();
-            emit this->fileReady(codec->toUnicode(array), url);
+            Q_EMIT this->fileReady(codec->toUnicode(array), url);
         }
     }
 }
@@ -177,16 +177,16 @@ void FileLoader::loadFile(const QUrl &url)
 DocumentAlert *DocumentHandler::externallyModifiedAlert()
 {
     auto alert = new DocumentAlert(i18nd("mauikittexteditor","File changed externally"), i18nd("mauikittexteditor","You can reload the file or save your changes now"), DocumentAlert::WARNING_LEVEL, Alerts::MODIFIED);
-    
+
     const auto reloadAction = [this]() {
-        emit this->loadFile(this->fileUrl());
+        Q_EMIT this->loadFile(this->fileUrl());
     };
-    
+
     const auto autoReloadAction = [this]() {
         this->setAutoReload(true);
-        emit this->loadFile(this->fileUrl());
+        Q_EMIT this->loadFile(this->fileUrl());
     };
-    
+
     alert->setActions({{i18nd("mauikittexteditor","Reload"), reloadAction}, {i18nd("mauikittexteditor","Auto Reload"), autoReloadAction}, {i18nd("mauikittexteditor","Ignore"), []() {}}});
     return alert;
 }
@@ -194,7 +194,7 @@ DocumentAlert *DocumentHandler::externallyModifiedAlert()
 DocumentAlert *DocumentHandler::canNotSaveAlert(const QString &details)
 {
     auto alert = new DocumentAlert(i18nd("mauikittexteditor","File can not be saved"), details, DocumentAlert::DANGER_LEVEL, Alerts::SAVE_ERROR);
-    
+
     alert->setActions({{i18nd("mauikittexteditor","Ignore"), []() {}}});
     return alert;
 }
@@ -202,11 +202,11 @@ DocumentAlert *DocumentHandler::canNotSaveAlert(const QString &details)
 DocumentAlert *DocumentHandler::missingAlert()
 {
     auto alert = new DocumentAlert(i18nd("mauikittexteditor","Your file was removed"), i18nd("mauikittexteditor","This file does not longer exist in your local storage, however you can save it again"), DocumentAlert::DANGER_LEVEL, Alerts::MISSING);
-    
+
     const auto saveAction = [this]() {
         this->saveAs(this->fileUrl());
     };
-    
+
     alert->setActions({{i18nd("mauikittexteditor","Save"), saveAction}});
     return alert;
 }
@@ -222,7 +222,7 @@ DocumentHandler::DocumentHandler(QObject *parent)
 , m_alerts(new Alerts(this))
 {
     ++m_instanceCount;
-    
+
     // start file loader thread implementation
     {
         FileLoader *m_loader = new FileLoader;
@@ -231,22 +231,22 @@ DocumentHandler::DocumentHandler(QObject *parent)
         connect(this, &DocumentHandler::loadFile, m_loader, &FileLoader::loadFile);
         connect(m_loader, &FileLoader::fileReady, [this](QString array, QUrl url) {
             this->setText(array);
-            
+
             if (this->textDocument()) {
                 this->textDocument()->setModified(false);
-                
+
                 this->isRich = Qt::mightBeRichText(this->text());
-                emit this->isRichChanged();
+                Q_EMIT this->isRichChanged();
             }
-            
-            emit this->loaded(url);
-            
+
+            Q_EMIT this->loaded(url);
+
             reset();
         });
         m_worker.start();
     }
     // end file loader thread implementation
-    
+
     connect(&m_autoSaveTimer, &QTimer::timeout, [this]() {
         if (m_autoSave && getModified() && !m_fileUrl.isEmpty()) {
             qDebug() << "Autosaving file" << m_fileUrl;
@@ -254,14 +254,14 @@ DocumentHandler::DocumentHandler(QObject *parent)
             m_autoSaveTimer.start(AUTOSAVE_TIMEOUT);
         }
     });
-    
+
     if (m_autoSave)
         m_autoSaveTimer.start(AUTOSAVE_TIMEOUT);
-    
+
     connect(this, &DocumentHandler::cursorPositionChanged, [this]() {
-        emit this->currentLineIndexChanged();
+        Q_EMIT this->currentLineIndexChanged();
     });
-    
+
     connect(this->m_watcher, &QFileSystemWatcher::fileChanged, [this](QString url) {
         if (this->fileUrl() == QUrl::fromLocalFile(url)) {
             // THE FILE WAS REMOVED
@@ -269,21 +269,21 @@ DocumentHandler::DocumentHandler(QObject *parent)
                 this->m_alerts->append(DocumentHandler::missingAlert());
                 return;
             }
-            
+
             // THE FILE CHANGED BUT STILL EXISTS LOCALLY
             if (m_internallyModified) {
                 m_internallyModified = false;
                 return;
             }
-            
+
             this->setExternallyModified(true);
-            
+
             if (!this->m_autoReload) {
                 this->m_alerts->append(DocumentHandler::externallyModifiedAlert());
                 return;
             }
-            
-            emit this->loadFile(this->fileUrl());
+
+            Q_EMIT this->loadFile(this->fileUrl());
         }
     });
 }
@@ -292,9 +292,9 @@ DocumentHandler::~DocumentHandler()
 {
     this->m_worker.quit();
     this->m_worker.wait();
-    
+
     --DocumentHandler::m_instanceCount;
-    
+
     if (!DocumentHandler::m_instanceCount) {
         delete DocumentHandler::m_repository;
         DocumentHandler::m_repository = nullptr;
@@ -305,7 +305,7 @@ void DocumentHandler::setText(const QString &text)
 {
     if (text != this->m_text) {
         this->m_text = text;
-        emit textChanged();
+        Q_EMIT textChanged();
     }
 }
 
@@ -318,9 +318,9 @@ void DocumentHandler::setAutoReload(const bool &value)
 {
     if (value == this->m_autoReload)
         return;
-    
+
     this->m_autoReload = value;
-    emit this->autoReloadChanged();
+    Q_EMIT this->autoReloadChanged();
 }
 
 bool DocumentHandler::autoSave() const
@@ -332,10 +332,10 @@ void DocumentHandler::setAutoSave(const bool &value)
 {
     if (m_autoSave == value)
         return;
-    
+
     m_autoSave = value;
-    emit autoSaveChanged();
-    
+    Q_EMIT autoSaveChanged();
+
     if (m_autoSave) {
         if (!m_autoSaveTimer.isActive())
             m_autoSaveTimer.start(AUTOSAVE_TIMEOUT);
@@ -347,7 +347,7 @@ bool DocumentHandler::getModified() const
 {
     if (auto doc = this->textDocument())
         return doc->isModified();
-    
+
     return false;
 }
 
@@ -360,16 +360,16 @@ void DocumentHandler::setExternallyModified(const bool &value)
 {
     if (value == this->m_externallyModified)
         return;
-    
+
     this->m_externallyModified = value;
-    emit this->externallyModifiedChanged();
+    Q_EMIT this->externallyModifiedChanged();
 }
 
 void DocumentHandler::setStyle()
 {
     if (!DocumentHandler::m_repository)
         DocumentHandler::m_repository = new KSyntaxHighlighting::Repository();
-    
+
     qDebug() << "Setting ths tyle" << m_formatName;
     if (!m_enableSyntaxHighlighting || m_formatName == "None") {
         this->m_highlighter->setDocument(nullptr);
@@ -378,35 +378,35 @@ void DocumentHandler::setStyle()
         //         this->m_highlighter->rehighlight();
         return;
     }
-    
+
     qDebug() << "Setting the style for syntax highligthing";
-    
+
     const auto def = m_repository->definitionForName(this->m_formatName);
     if (!def.isValid()) {
         qDebug() << "Highliging definition is not valid" << def.name() << def.filePath() << def.author() << m_formatName;
         return;
     }
-    
+
     if (!m_highlighter->document()) {
         this->m_highlighter->setDocument(this->textDocument());
     }
-    
+
     qDebug() << "Highliging definition info" << def.name() << def.filePath() << def.author() << m_formatName;
-    
+
     this->m_highlighter->setDefinition(def);
-    
+
     if (m_theme.isEmpty()) {
         const bool isDark = DocumentHandler::isDark(this->m_backgroundColor);
         const auto style = DocumentHandler::m_repository->defaultTheme(isDark ? KSyntaxHighlighting::Repository::DarkTheme : KSyntaxHighlighting::Repository::LightTheme);
         this->m_highlighter->setTheme(style);
-        
+
     } else {
         qDebug() << "Applying theme << " << m_theme << DocumentHandler::m_repository->theme(m_theme).isValid();
         const auto style = DocumentHandler::m_repository->theme(m_theme);
         this->m_highlighter->setTheme(style);
         this->m_highlighter->rehighlight();
     }
-    
+
     refreshAllBlocks();
 }
 
@@ -415,7 +415,7 @@ void DocumentHandler::refreshAllBlocks()
     if (textDocument()) {
         for (QTextBlock it = textDocument()->begin(); it != textDocument()->end(); it = it.next())
         {
-            emit this->textDocument()->documentLayout()->updateBlock(it);
+            Q_EMIT this->textDocument()->documentLayout()->updateBlock(it);
         }
     }
 }
@@ -429,9 +429,9 @@ void DocumentHandler::setFormatName(const QString &formatName)
 {
     if (this->m_formatName != formatName) {
         this->m_formatName = formatName;
-        emit this->formatNameChanged();
+        Q_EMIT this->formatNameChanged();
     }
-    
+
     this->setStyle();
 }
 
@@ -444,10 +444,10 @@ void DocumentHandler::setBackgroundColor(const QColor &color)
 {
     if (this->m_backgroundColor == color)
         return;
-    
+
     this->m_backgroundColor = color;
-    emit this->backgroundColorChanged();
-    
+    Q_EMIT this->backgroundColorChanged();
+
     if (!DocumentHandler::m_repository)
         DocumentHandler::m_repository = new KSyntaxHighlighting::Repository();
 }
@@ -465,22 +465,22 @@ QQuickTextDocument *DocumentHandler::document() const
 void DocumentHandler::setDocument(QQuickTextDocument *document)
 {
     this->m_document = document;
-    emit documentChanged();
-    
+    Q_EMIT documentChanged();
+
     if (this->textDocument()) {
         this->textDocument()->setModified(false);
         connect(this->textDocument(), &QTextDocument::modificationChanged, this, &DocumentHandler::modifiedChanged);
-        
+
         connect(this->textDocument(), &QTextDocument::blockCountChanged, this, &DocumentHandler::lineCountChanged);
-        
+
         //          connect(this->textDocument(), &QTextDocument::cursorPositionChanged, [this](const QTextCursor &)
         //                 {
         //                     qDebug() << "Cursors position changed";
-        //                     emit currentLineIndexChanged();
+        //                     Q_EMIT currentLineIndexChanged();
         //                 });
-        
+
         this->load(m_fileUrl);
-        
+
         QTextOption textOptions = this->textDocument()->defaultTextOption();
         textOptions.setTabStopDistance(m_tabSpace);
         textDocument()->setDefaultTextOption(textOptions);
@@ -493,14 +493,14 @@ int DocumentHandler::cursorPosition() const
 }
 
 void DocumentHandler::setCursorPosition(int position)
-{    
+{
     if(m_cursorPosition == position)
     {
         return;
     }
-    
+
     m_cursorPosition = position;
-    emit cursorPositionChanged();
+    Q_EMIT cursorPositionChanged();
 }
 
 int DocumentHandler::selectionStart() const
@@ -512,9 +512,9 @@ void DocumentHandler::setSelectionStart(int position)
 {
     if (position == m_selectionStart)
         return;
-    
+
     m_selectionStart = position;
-    emit selectionStartChanged();
+    Q_EMIT selectionStartChanged();
 }
 
 int DocumentHandler::selectionEnd() const
@@ -526,9 +526,9 @@ void DocumentHandler::setSelectionEnd(int position)
 {
     if (position == m_selectionEnd)
         return;
-    
+
     m_selectionEnd = position;
-    emit selectionEndChanged();
+    Q_EMIT selectionEndChanged();
 }
 
 QString DocumentHandler::fontFamily() const
@@ -545,7 +545,7 @@ void DocumentHandler::setFontFamily(const QString &family)
     QTextCharFormat format;
     format.setFontFamily(family);
     mergeFormatOnWordOrSelection(format);
-    emit fontFamilyChanged();
+    Q_EMIT fontFamilyChanged();
 }
 
 QColor DocumentHandler::textColor() const
@@ -562,7 +562,7 @@ void DocumentHandler::setTextColor(const QColor &color)
     QTextCharFormat format;
     format.setForeground(QBrush(color));
     mergeFormatOnWordOrSelection(format);
-    emit textColorChanged();
+    Q_EMIT textColorChanged();
 }
 
 Qt::Alignment DocumentHandler::alignment() const
@@ -579,7 +579,7 @@ void DocumentHandler::setAlignment(Qt::Alignment alignment)
     format.setAlignment(alignment);
     QTextCursor cursor = textCursor();
     cursor.mergeBlockFormat(format);
-    emit alignmentChanged();
+    Q_EMIT alignmentChanged();
 }
 
 bool DocumentHandler::bold() const
@@ -595,7 +595,7 @@ void DocumentHandler::setBold(bool bold)
     QTextCharFormat format;
     format.setFontWeight(bold ? QFont::Bold : QFont::Normal);
     mergeFormatOnWordOrSelection(format);
-    emit boldChanged();
+    Q_EMIT boldChanged();
 }
 
 bool DocumentHandler::uppercase() const
@@ -611,7 +611,7 @@ void DocumentHandler::setUppercase(bool uppercase)
     QTextCharFormat format;
     format.setFontCapitalization(uppercase ? QFont::AllUppercase : QFont::AllLowercase);
     mergeFormatOnWordOrSelection(format);
-    emit uppercaseChanged();
+    Q_EMIT uppercaseChanged();
 }
 
 bool DocumentHandler::italic() const
@@ -627,7 +627,7 @@ void DocumentHandler::setItalic(bool italic)
     QTextCharFormat format;
     format.setFontItalic(italic);
     mergeFormatOnWordOrSelection(format);
-    emit italicChanged();
+    Q_EMIT italicChanged();
 }
 
 bool DocumentHandler::underline() const
@@ -643,7 +643,7 @@ void DocumentHandler::setUnderline(bool underline)
     QTextCharFormat format;
     format.setFontUnderline(underline);
     mergeFormatOnWordOrSelection(format);
-    emit underlineChanged();
+    Q_EMIT underlineChanged();
 }
 
 bool DocumentHandler::getIsRich() const
@@ -664,37 +664,37 @@ void DocumentHandler::setFontSize(int size)
 {
     if (size <= 0)
         return;
-    
+
     QTextCursor cursor = textCursor();
     if (cursor.isNull())
         return;
-    
+
     if (!cursor.hasSelection())
         cursor.select(QTextCursor::WordUnderCursor);
-    
+
     if (cursor.charFormat().property(QTextFormat::FontPointSize).toInt() == size)
         return;
-    
+
     QTextCharFormat format;
     format.setFontPointSize(size);
     mergeFormatOnWordOrSelection(format);
-    emit fontSizeChanged();
+    Q_EMIT fontSizeChanged();
 }
 
 void DocumentHandler::setTabSpace(qreal value)
 {
     if (m_tabSpace == value)
         return;
-    
+
     m_tabSpace = value;
-    
+
     if (textDocument()) {
         QTextOption textOptions = this->textDocument()->defaultTextOption();
         textOptions.setTabStopDistance(m_tabSpace);
         textDocument()->setDefaultTextOption(textOptions);
     }
-    
-    emit tabSpaceChanged();
+
+    Q_EMIT tabSpaceChanged();
     refreshAllBlocks();
 }
 
@@ -726,29 +726,29 @@ void DocumentHandler::setFileUrl(const QUrl &url)
 {
     if (url == m_fileUrl)
         return;
-    
+
     m_fileUrl = url;
-    
+
     load(m_fileUrl);
-    
-    emit fileUrlChanged();
-    emit fileInfoChanged();
+
+    Q_EMIT fileUrlChanged();
+    Q_EMIT fileInfoChanged();
 }
 
 QVariantMap DocumentHandler::fileInfo() const
 {
-    
-    const QFileInfo file(m_fileUrl.toLocalFile());    
+
+    const QFileInfo file(m_fileUrl.toLocalFile());
     if(file.exists())
     {
         return QVariantMap();
     }
-    
+
     QVariantMap map = {
         {FMH::MODEL_NAME[FMH::MODEL_KEY::LABEL], file.fileName()},
-        {FMH::MODEL_NAME[FMH::MODEL_KEY::NAME], file.fileName()}        
-    };    
-    
+        {FMH::MODEL_NAME[FMH::MODEL_KEY::NAME], file.fileName()}
+    };
+
     return map;
 }
 
@@ -757,21 +757,21 @@ void DocumentHandler::load(const QUrl &url)
     qDebug() << "TRYING TO LOAD FILE << " << url << url.isEmpty();
     if (!textDocument())
         return;
-    
+
     if (m_fileUrl.isLocalFile() && !FMH::fileExists(m_fileUrl))
         return;
-    
+
     QQmlEngine *engine = qmlEngine(this);
     if (!engine) {
         qWarning() << "load() called before DocumentHandler has QQmlEngine";
         return;
     }
-    
+
     this->m_watcher->removePaths(this->m_watcher->files());
     this->m_watcher->addPath(m_fileUrl.toLocalFile());
-    
-    emit this->loadFile(m_fileUrl);
-    
+
+    Q_EMIT this->loadFile(m_fileUrl);
+
     if (m_enableSyntaxHighlighting) {
         this->setFormatName(DocumentHandler::getLanguageNameFromFileName(m_fileUrl));
     }
@@ -781,42 +781,42 @@ void DocumentHandler::saveAs(const QUrl &url)
 {
     if (url.isEmpty() || !url.isValid())
         return;
-    
+
     QTextDocument *doc = this->textDocument();
     if (!doc)
         return;
-    
+
     this->m_internallyModified = true;
-    
+
     // 	QTextDocumentWriter textWriter(url.toLocalFile());
     // 	if(!textWriter.write(this->textDocument()))
     // 	{
-    // 		emit error(i18nd("mauikittexteditor","Cannot save file ")+ url.toString());
+    // 		Q_EMIT error(i18nd("mauikittexteditor","Cannot save file ")+ url.toString());
     //         qWarning() << "can not save file" << textWriter.supportedDocumentFormats() << textWriter.format();
     // 		this->m_alerts->append(this->canNotSaveAlert(i18nd("mauikittexteditor","Cannot save file ")+ url.toString()));
     // 		return;
     // 	}
-    
+
     const QString filePath = url.toLocalFile();
     const bool isHtml = QFileInfo(filePath).suffix().contains(QLatin1String("html"));
     QFile file(filePath);
     if (!file.open(QFile::WriteOnly | QFile::Truncate | (isHtml ? QFile::NotOpen : QFile::Text))) {
-        emit error(i18nd("mauikittexteditor","Cannot save: ") + file.errorString());
+        Q_EMIT error(i18nd("mauikittexteditor","Cannot save: ") + file.errorString());
         this->m_alerts->append(this->canNotSaveAlert(i18nd("mauikittexteditor","Cannot save file ") + file.errorString() + url.toString()));
-        
+
         return;
     }
     file.write((isHtml ? doc->toHtml() : doc->toPlainText()).toUtf8());
     file.close();
-    emit fileSaved();
-    
+    Q_EMIT fileSaved();
+
     doc->setModified(false);
-    
+
     if (url == m_fileUrl)
         return;
-    
+
     m_fileUrl = url;
-    emit fileUrlChanged();
+    Q_EMIT fileUrlChanged();
 }
 
 const QString DocumentHandler::getLanguageNameFromFileName(const QUrl &fileName)
@@ -824,7 +824,7 @@ const QString DocumentHandler::getLanguageNameFromFileName(const QUrl &fileName)
     if (!DocumentHandler::m_repository)
         DocumentHandler::m_repository = new KSyntaxHighlighting::Repository();
     const auto res = DocumentHandler::m_repository->definitionForFileName(fileName.toString());
-    
+
     return res.isValid() ? res.name() : QString();
 }
 
@@ -832,7 +832,7 @@ const QStringList DocumentHandler::getLanguageNameList()
 {
     if (!DocumentHandler::m_repository)
         m_repository = new KSyntaxHighlighting::Repository();
-    
+
     const auto definitions = DocumentHandler::m_repository->definitions();
     return std::accumulate(definitions.constBegin(), definitions.constEnd(), QStringList(), [](QStringList &languages, const auto &definition) -> QStringList {
         languages.append(definition.name());
@@ -843,13 +843,13 @@ const QStringList DocumentHandler::getLanguageNameList()
 
 void DocumentHandler::reset()
 {
-    emit fontFamilyChanged();
-    emit alignmentChanged();
-    emit boldChanged();
-    emit italicChanged();
-    emit underlineChanged();
-    emit fontSizeChanged();
-    emit textColorChanged();
+    Q_EMIT fontFamilyChanged();
+    Q_EMIT alignmentChanged();
+    Q_EMIT boldChanged();
+    Q_EMIT italicChanged();
+    Q_EMIT underlineChanged();
+    Q_EMIT fontSizeChanged();
+    Q_EMIT textColorChanged();
 }
 
 QTextCursor DocumentHandler::textCursor() const
@@ -857,7 +857,7 @@ QTextCursor DocumentHandler::textCursor() const
     QTextDocument *doc = textDocument();
     if (!doc)
         return QTextCursor();
-    
+
     QTextCursor cursor = QTextCursor(doc);
     if (m_selectionStart != m_selectionEnd) {
         cursor.setPosition(m_selectionStart);
@@ -872,7 +872,7 @@ QTextDocument *DocumentHandler::textDocument() const
 {
     if (!m_document)
         return nullptr;
-    
+
     return m_document->textDocument();
 }
 
@@ -888,38 +888,38 @@ void DocumentHandler::find(const QString &query,const bool &forward)
 {
     qDebug() << "Asked to find" << query;
     QTextDocument *doc = textDocument();
-    
+
     if (!doc) {
         return;
     }
-    
-    QTextDocument::FindFlags searchFlags;    
+
+    QTextDocument::FindFlags searchFlags;
     QTextDocument::FindFlags newFlags = searchFlags;
-    
+
     if (!forward)
     {
         newFlags = searchFlags | QTextDocument::FindBackward;
     }
-    
+
     if (m_findCaseSensitively)
     {
         newFlags = newFlags | QTextDocument::FindCaseSensitively;
     }
-    
+
     if (m_findWholeWords)
     {
         newFlags = newFlags | QTextDocument::FindWholeWords;
     }
-    
+
     QTextCursor start = this->textCursor();
-    
+
     if(query != m_searchQuery )
     {
         start.movePosition(QTextCursor::Start, QTextCursor::MoveAnchor);
         m_searchQuery = query;
     }
-    
-    if (!start.isNull() && !start.atEnd()) 
+
+    if (!start.isNull() && !start.atEnd())
     {
         QTextCursor found = doc->find(m_searchQuery, start, newFlags);
         if (found.isNull())
@@ -928,20 +928,20 @@ void DocumentHandler::find(const QString &query,const bool &forward)
                 start.movePosition (QTextCursor::End, QTextCursor::MoveAnchor);
             else
                 start.movePosition (QTextCursor::Start, QTextCursor::MoveAnchor);
-            
+
             this->setCursorPosition(start.position());
-            
+
             found = doc->find(m_searchQuery, start, newFlags);
         }
-        
+
         if (!found.isNull())
         {
             //              found.movePosition(QTextCursor::WordRight, QTextCursor::MoveAnchor);
             setSelectionStart(found.selectionStart());
             setSelectionEnd(found.selectionEnd());
             setCursorPosition(found.position());
-            emit searchFound(selectionStart(), selectionEnd());
-        }   
+            Q_EMIT searchFound(selectionStart(), selectionEnd());
+        }
     }
 }
 
@@ -950,79 +950,79 @@ void DocumentHandler::replace(const QString &query, const QString &value)
     if(value.isEmpty())
     {
         return;
-    }    
-    
+    }
+
     if (this->textDocument()) {
-        
+
         if(m_searchQuery.isEmpty() || query != m_searchQuery)
         {
             find(query);
         }
-        
+
         auto cursor = this->textCursor();
         cursor.beginEditBlock();
         cursor.insertText(value);
         cursor.endEditBlock();
-        
+
         find(query);
-    }    
+    }
 }
 
 void DocumentHandler::replaceAll(const QString &query, const QString &value)
 {
     QTextDocument *doc = textDocument();
-    
+
     if (!doc) {
         return;
     }
-    
+
     QTextCursor newCursor(doc);
     newCursor.movePosition(QTextCursor::Start, QTextCursor::MoveAnchor);
-    
+
     if(newCursor.isNull() || newCursor.atEnd())
     {
         return;
     }
-    
-    QTextDocument::FindFlags searchFlags;    
+
+    QTextDocument::FindFlags searchFlags;
     QTextDocument::FindFlags newFlags = searchFlags;
-    
+
     if (m_findCaseSensitively)
     {
         newFlags = searchFlags | QTextDocument::FindCaseSensitively;
     }
-    
+
     if (m_findWholeWords)
     {
         newFlags = searchFlags | QTextDocument::FindWholeWords;
     }
-    
+
     while (!newCursor.isNull() && !newCursor.atEnd()) {
         newCursor = doc->find(query, newCursor, newFlags);
-        
-        if (!newCursor.isNull()) {            
-            
+
+        if (!newCursor.isNull()) {
+
             //             newCursor.movePosition(QTextCursor::NoMove,
             //                                    QTextCursor::KeepAnchor);
-            
+
             newCursor.beginEditBlock();
             newCursor.insertText(value);
             newCursor.endEditBlock();
-            
+
         }
-    }   
+    }
 }
 
 bool DocumentHandler::isFoldable(const int &line) const
 {
     if(!m_highlighter)
         return false;
-    
+
     if(auto doc = this->textDocument())
     {
         return m_highlighter->startsFoldingRegion(doc->findBlockByLineNumber(line));
     }
-    
+
     return false;
 }
 
@@ -1030,22 +1030,22 @@ bool DocumentHandler::isFolded(const int &line) const
 {
     if(!m_highlighter)
         return false;
-    
+
     if(auto doc = this->textDocument())
-    {        
+    {
         auto block = doc->findBlockByLineNumber(line);
-        
+
         if (!block.isValid())
             return false;
-        
+
         const auto nextBlock = block.next();
-        
+
         if (!nextBlock.isValid())
             return false;
-        
+
         return !nextBlock.isVisible();
     }
-    
+
     return false;
 }
 
@@ -1053,37 +1053,37 @@ void DocumentHandler::toggleFold(const int &line)
 {
     if(!m_highlighter)
         return;
-    
+
     if(auto doc = this->textDocument())
-    {        
+    {
         auto startBlock = doc->findBlockByLineNumber(line);
-        
+
         // we also want to fold the last line of the region, therefore the ".next()"
         const auto endBlock =
         m_highlighter->findFoldingRegionEnd(startBlock).next();
-        
+
         qDebug() << "Fold line"<< line << startBlock.position() << endBlock.position() << doc->blockCount();
         // fold
         auto block = startBlock.next();
-        while (block.isValid() && block != endBlock) 
+        while (block.isValid() && block != endBlock)
         {
             block.setVisible(false);
             block.setLineCount(0);
             block = block.next();
         }
-        
-        
+
+
         for (QTextBlock it = startBlock; it != endBlock; it = it.next())
         {
-            emit this->textDocument()->documentLayout()->updateBlock(it);
+            Q_EMIT this->textDocument()->documentLayout()->updateBlock(it);
         }
-        
+
         // redraw document
         //         doc->markContentsDirty(startBlock.position(), endBlock.position());
         qDebug() << "Fold line"<< line << startBlock.position() << endBlock.position() << doc->blockCount();
-        
+
         //         // update scrollbars
-        emit doc->documentLayout()->documentSizeChanged(
+        Q_EMIT doc->documentLayout()->documentSizeChanged(
             doc->documentLayout()->documentSize());
     }
 }
@@ -1091,11 +1091,11 @@ void DocumentHandler::toggleFold(const int &line)
 int DocumentHandler::lineHeight(const int &line)
 {
     QTextDocument *doc = textDocument();
-    
+
     if (!doc) {
         return 0;
     }
-    
+
     return int(doc->documentLayout()->blockBoundingRect(doc->findBlockByLineNumber(line)).height());
 }
 
@@ -1107,10 +1107,10 @@ int DocumentHandler::lineCount()
 }
 
 int DocumentHandler::getCurrentLineIndex()
-{    
+{
     if (!this->textDocument())
         return -1;
-    
+
     return this->textDocument()->findBlock(m_cursorPosition).blockNumber();
 }
 
@@ -1119,7 +1119,7 @@ int DocumentHandler::goToLine(const int& line)
     if (!this->textDocument())
         return this->cursorPosition();
     const auto block = this->textDocument()->findBlockByLineNumber(line);
-    return block.position() + block.length()-1;     
+    return block.position() + block.length()-1;
 }
 
 void DocumentHandler::setEnableSyntaxHighlighting(const bool &value)
@@ -1127,16 +1127,16 @@ void DocumentHandler::setEnableSyntaxHighlighting(const bool &value)
     if (m_enableSyntaxHighlighting == value) {
         return;
     }
-    
+
     m_enableSyntaxHighlighting = value;
-    
+
     if (!m_enableSyntaxHighlighting) {
         this->setFormatName("None");
     } else {
         this->setFormatName(DocumentHandler::getLanguageNameFromFileName(m_fileUrl));
     }
-    
-    emit enableSyntaxHighlightingChanged();
+
+    Q_EMIT enableSyntaxHighlightingChanged();
 }
 
 bool DocumentHandler::enableSyntaxHighlighting() const
@@ -1148,11 +1148,11 @@ void DocumentHandler::setTheme(const QString &theme)
 {
     if (m_theme == theme)
         return;
-    
+
     m_theme = theme;
     setStyle();
     qDebug() << "changinf the theme<< " << theme << m_theme;
-    emit themeChanged();
+    Q_EMIT themeChanged();
 }
 
 QString DocumentHandler::theme() const
